@@ -29,11 +29,13 @@ from transformers import (
     XLNetLMHeadModel,
     XLNetTokenizer,
 )
+from transformers import BertTokenizerFast
 
 from textgen.config.model_args import LanguageGenerationArgs
 from textgen.language_generation.language_generation_utils import PREPROCESSING_FUNCTIONS
 from loguru import logger
-use_cuda = torch.cuda.is_available()
+
+has_cuda = torch.cuda.is_available()
 os.environ["TOKENIZERS_PARALLELISM"] = "FALSE"
 os.environ["KMP_DUPLICATE_LIB_OK"] = "TRUE"
 MAX_LENGTH = int(10000)  # Hardcoded max length to avoid infinite loop
@@ -41,13 +43,15 @@ MAX_LENGTH = int(10000)  # Hardcoded max length to avoid infinite loop
 
 class LanguageGenerationModel:
     def __init__(
-        self,
-        model_type,
-        model_name,
-        args=None,
-        use_cuda=use_cuda,
-        cuda_device=-1,
-        **kwargs,
+            self,
+            model_type,
+            model_name,
+            args=None,
+            use_cuda=has_cuda,
+            cuda_device=-1,
+            model=None,
+            tokenizer=None,
+            **kwargs,
     ):
 
         """
@@ -102,46 +106,53 @@ class LanguageGenerationModel:
             self.device = "cpu"
         logger.debug(f"Device: {self.device}")
 
-        if self.args.special_tokens_list:
-            self.tokenizer.add_tokens(
-                self.args.special_tokens_list, special_tokens=True
-            )
-            self.model.resize_token_embeddings(len(self.tokenizer))
-
         self.args.model_name = model_name
         self.args.model_type = model_type
 
         config_class, model_class, tokenizer_class = MODEL_CLASSES[model_type]
 
-        if self.args.tokenizer_name:
-            self.tokenizer = tokenizer_class.from_pretrained(
-                self.args.tokenizer_name, cache_dir=self.args.cache_dir
-            )
+        if tokenizer is None:
+            # Special tokenizer for chinese gpt2 model
+            if self.args.model_name in ['ckiplab/gpt2-base-chinese']:
+                tokenizer_class = BertTokenizerFast
+
+            if self.args.tokenizer_name:
+                self.tokenizer = tokenizer_class.from_pretrained(
+                    self.args.tokenizer_name
+                )
+            else:
+                self.tokenizer = tokenizer_class.from_pretrained(
+                    model_name, **kwargs
+                )
+                self.args.tokenizer_name = model_name
         else:
-            self.tokenizer = tokenizer_class.from_pretrained(
-                model_name, cache_dir=self.args.cache_dir, **kwargs
-            )
-            self.args.tokenizer_name = model_name
+            self.tokenizer = tokenizer
 
         if self.args.config_name:
             self.config = config_class.from_pretrained(
-                self.args.config_name, cache_dir=self.args.cache_dir
+                self.args.config_name
             )
         else:
             self.config = config_class.from_pretrained(
-                model_name, cache_dir=self.args.cache_dir, **kwargs
+                model_name, **kwargs
             )
+        if model is None:
+            self.model = model_class.from_pretrained(
+                model_name,
+                config=self.config,
+                **kwargs,
+            )
+        else:
+            self.model = model
 
-        self.model = model_class.from_pretrained(
-            model_name,
-            config=self.config,
-            cache_dir=self.args.cache_dir,
-            **kwargs,
-        )
-
+        if self.args.special_tokens_list:
+            self.tokenizer.add_tokens(
+                self.args.special_tokens_list, special_tokens=True
+            )
+            self.model.resize_token_embeddings(len(self.tokenizer))
         self.model.to(self.device)
 
-    def generate(self, prompt=None, args=None, verbose=True):
+    def generate(self, prompt=None, args=None, verbose=False, add_cls_head=False):
 
         """
         Generate text using a LanguageGenerationModel
@@ -150,6 +161,7 @@ class LanguageGenerationModel:
             prompt (optional): A prompt text for the model. If given, will override args.prompt
             args (optional): Optional changes to the args dict of the model. Any changes made will persist for the model.
             verbose (optional): If verbose, generated text will be logged to the console.
+            add_cls_head (optional): If True, add cls before prompt.
         Returns:
             generated_sequences: Sequences of text generated by the model.
         """  # noqa: ignore flake8"
@@ -182,6 +194,11 @@ class LanguageGenerationModel:
                 return_tensors="pt",
                 add_space_before_punct_symbol=True,
             )
+        elif add_cls_head:
+            encoded_prompt = [tokenizer.cls_token_id] + tokenizer.encode(
+                prompt_text, add_special_tokens=False
+            )
+            encoded_prompt = torch.tensor([encoded_prompt], dtype=torch.long)
         else:
             encoded_prompt = tokenizer.encode(
                 prompt_text, add_special_tokens=False, return_tensors="pt"
@@ -197,6 +214,11 @@ class LanguageGenerationModel:
             repetition_penalty=args.repetition_penalty,
             do_sample=args.do_sample,
             num_return_sequences=args.num_return_sequences,
+            length_penalty=args.length_penalty,
+            early_stopping=args.early_stopping,
+            bos_token_id=self.tokenizer.bos_token_id,
+            pad_token_id=self.tokenizer.pad_token_id,
+            eos_token_id=self.tokenizer.eos_token_id,
         )
 
         # Remove the batch dimension when returning multiple sequences
@@ -207,30 +229,15 @@ class LanguageGenerationModel:
 
         for generated_sequence_idx, generated_sequence in enumerate(output_sequences):
             if verbose:
-                logger.info(
-                    "=== GENERATED SEQUENCE {} ===".format(generated_sequence_idx + 1)
-                )
+                logger.info("=== GENERATED SEQUENCE {} ===".format(generated_sequence_idx + 1))
             generated_sequence = generated_sequence.tolist()
-
             # Decode text
-            text = tokenizer.decode(
-                generated_sequence, clean_up_tokenization_spaces=True
-            )
-
+            text = tokenizer.decode(generated_sequence, skip_special_tokens=True)
             # Remove all text after the stop token
             text = text[: text.find(args.stop_token) if args.stop_token else None]
 
             # Add the prompt at the beginning of the sequence. Remove the excess text that was used for pre-processing
-            total_sequence = (
-                prompt_text
-                + text[
-                    len(
-                        tokenizer.decode(
-                            encoded_prompt[0], clean_up_tokenization_spaces=True
-                        )
-                    ) :
-                ]
-            )
+            total_sequence = (prompt_text + text[len(tokenizer.decode(encoded_prompt[0], skip_special_tokens=True)):])
 
             generated_sequences.append(total_sequence)
             if verbose:
