@@ -56,6 +56,7 @@ from transformers.optimization import (
     get_cosine_with_hard_restarts_schedule_with_warmup,
     get_polynomial_decay_schedule_with_warmup,
 )
+from transformers import BertTokenizerFast
 
 from textgen.config.model_args import LanguageModelingArgs
 from textgen.custom_models.models import ElectraForLanguageModelingModel
@@ -79,7 +80,7 @@ MODEL_CLASSES = {
     "openai-gpt": (OpenAIGPTConfig, OpenAIGPTLMHeadModel, OpenAIGPTTokenizer),
     "roberta": (RobertaConfig, RobertaForMaskedLM, RobertaTokenizer),
 }
-use_cuda = torch.cuda.is_available()
+has_cuda = torch.cuda.is_available()
 os.environ["TOKENIZERS_PARALLELISM"] = "FALSE"
 os.environ["KMP_DUPLICATE_LIB_OK"] = "TRUE"
 
@@ -93,8 +94,10 @@ class LanguageModelingModel:
             discriminator_name=None,
             train_files=None,
             args=None,
-            use_cuda=use_cuda,
+            use_cuda=has_cuda,
             cuda_device=-1,
+            model=None,
+            tokenizer=None,
             **kwargs,
     ):
 
@@ -157,40 +160,47 @@ class LanguageModelingModel:
         self.args.model_type = model_type
 
         config_class, model_class, tokenizer_class = MODEL_CLASSES[model_type]
-        self.tokenizer_class = tokenizer_class
-        new_tokenizer = False
-
-        if self.args.tokenizer_name:
-            self.tokenizer = tokenizer_class.from_pretrained(self.args.tokenizer_name, cache_dir=self.args.cache_dir)
-        elif self.args.model_name:
-            if self.args.model_name == "electra":
-                self.tokenizer = tokenizer_class.from_pretrained(
-                    generator_name, cache_dir=self.args.cache_dir, **kwargs
-                )
-                self.args.tokenizer_name = self.args.model_name
-            else:
-                self.tokenizer = tokenizer_class.from_pretrained(model_name, cache_dir=self.args.cache_dir, **kwargs)
-                self.args.tokenizer_name = self.args.model_name
-        else:
-            if not train_files:
-                raise ValueError(
-                    "model_name and tokenizer_name are not specified."
-                    "You must specify train_files to train a Tokenizer."
-                )
-            else:
-                self.train_tokenizer(train_files)
-                new_tokenizer = True
 
         if self.args.config_name:
-            self.config = config_class.from_pretrained(self.args.config_name, cache_dir=self.args.cache_dir)
+            self.config = config_class.from_pretrained(self.args.config_name)
         elif self.args.model_name and self.args.model_name != "electra":
-            self.config = config_class.from_pretrained(model_name, cache_dir=self.args.cache_dir, **kwargs)
+            self.config = config_class.from_pretrained(model_name, **kwargs)
         else:
             self.config = config_class(**self.args.config, **kwargs)
         if self.args.vocab_size:
             self.config.vocab_size = self.args.vocab_size
-        if new_tokenizer:
-            self.config.vocab_size = len(self.tokenizer)
+
+        new_tokenizer = False
+        if tokenizer is None:
+            # Special tokenizer for chinese gpt2 model
+            if self.args.model_name in ['ckiplab/gpt2-base-chinese']:
+                tokenizer_class = BertTokenizerFast
+
+            self.tokenizer_class = tokenizer_class
+            if self.args.tokenizer_name:
+                self.tokenizer = tokenizer_class.from_pretrained(self.args.tokenizer_name)
+            elif self.args.model_name:
+                if self.args.model_name == "electra":
+                    self.tokenizer = tokenizer_class.from_pretrained(
+                        generator_name, **kwargs
+                    )
+                    self.args.tokenizer_name = self.args.model_name
+                else:
+                    self.tokenizer = tokenizer_class.from_pretrained(model_name, **kwargs)
+                    self.args.tokenizer_name = self.args.model_name
+            else:
+                if not train_files:
+                    raise ValueError(
+                        "model_name and tokenizer_name are not specified."
+                        "You must specify train_files to train a Tokenizer."
+                    )
+                else:
+                    self.train_tokenizer(train_files)
+                    new_tokenizer = True
+            if new_tokenizer:
+                self.config.vocab_size = len(self.tokenizer)
+        else:
+            self.tokenizer = tokenizer
 
         if self.args.model_type == "electra":
             if generator_name:
@@ -220,11 +230,56 @@ class LanguageModelingModel:
         else:
             self.args.block_size = min(self.args.block_size, self.tokenizer.model_max_length, self.args.max_seq_length)
 
-        if self.args.model_name:
-            if self.args.model_type == "electra":
-                if self.args.model_name == "electra":
-                    generator_model = ElectraForMaskedLM.from_pretrained(generator_name)
-                    discriminator_model = ElectraForPreTraining.from_pretrained(discriminator_name)
+        if model is None:
+            if self.args.model_name:
+                if self.args.model_type == "electra":
+                    if self.args.model_name == "electra":
+                        generator_model = ElectraForMaskedLM.from_pretrained(generator_name)
+                        discriminator_model = ElectraForPreTraining.from_pretrained(discriminator_name)
+                        self.model = ElectraForLanguageModelingModel(
+                            config=self.config,
+                            generator_model=generator_model,
+                            discriminator_model=discriminator_model,
+                            generator_config=self.generator_config,
+                            discriminator_config=self.discriminator_config,
+                            tie_generator_and_discriminator_embeddings=self.args.tie_generator_and_discriminator_embeddings,
+                        )
+                        model_to_resize = (
+                            self.model.generator_model.module
+                            if hasattr(self.model.generator_model, "module")
+                            else self.model.generator_model
+                        )
+                        model_to_resize.resize_token_embeddings(len(self.tokenizer))
+
+                        model_to_resize = (
+                            self.model.discriminator_model.module
+                            if hasattr(self.model.discriminator_model, "module")
+                            else self.model.discriminator_model
+                        )
+                        model_to_resize.resize_token_embeddings(len(self.tokenizer))
+                        self.model.generator_model = generator_model
+                        self.model.discriminator_model = discriminator_model
+                    else:
+                        self.model = model_class.from_pretrained(
+                            model_name,
+                            config=self.config,
+                            generator_config=self.generator_config,
+                            discriminator_config=self.discriminator_config,
+                            **kwargs,
+                        )
+                        self.model.load_state_dict(
+                            torch.load(os.path.join(self.args.model_name, "pytorch_model.bin"),
+                                       map_location=self.device)
+                        )
+                else:
+                    self.model = model_class.from_pretrained(
+                        model_name, config=self.config, **kwargs,
+                    )
+            else:
+                logger.info(" Training language model from scratch")
+                if self.args.model_type == "electra":
+                    generator_model = ElectraForMaskedLM(config=self.generator_config)
+                    discriminator_model = ElectraForPreTraining(config=self.discriminator_config)
                     self.model = ElectraForLanguageModelingModel(
                         config=self.config,
                         generator_model=generator_model,
@@ -246,55 +301,12 @@ class LanguageModelingModel:
                         else self.model.discriminator_model
                     )
                     model_to_resize.resize_token_embeddings(len(self.tokenizer))
-                    self.model.generator_model = generator_model
-                    self.model.discriminator_model = discriminator_model
                 else:
-                    self.model = model_class.from_pretrained(
-                        model_name,
-                        config=self.config,
-                        cache_dir=self.args.cache_dir,
-                        generator_config=self.generator_config,
-                        discriminator_config=self.discriminator_config,
-                        **kwargs,
-                    )
-                    self.model.load_state_dict(
-                        torch.load(os.path.join(self.args.model_name, "pytorch_model.bin"), map_location=self.device)
-                    )
-            else:
-                self.model = model_class.from_pretrained(
-                    model_name, config=self.config, cache_dir=self.args.cache_dir, **kwargs,
-                )
+                    self.model = model_class(config=self.config)
+                    model_to_resize = self.model.module if hasattr(self.model, "module") else self.model
+                    model_to_resize.resize_token_embeddings(len(self.tokenizer))
         else:
-            logger.info(" Training language model from scratch")
-            if self.args.model_type == "electra":
-                generator_model = ElectraForMaskedLM(config=self.generator_config)
-                discriminator_model = ElectraForPreTraining(config=self.discriminator_config)
-                self.model = ElectraForLanguageModelingModel(
-                    config=self.config,
-                    generator_model=generator_model,
-                    discriminator_model=discriminator_model,
-                    generator_config=self.generator_config,
-                    discriminator_config=self.discriminator_config,
-                    tie_generator_and_discriminator_embeddings=self.args.tie_generator_and_discriminator_embeddings,
-                )
-                model_to_resize = (
-                    self.model.generator_model.module
-                    if hasattr(self.model.generator_model, "module")
-                    else self.model.generator_model
-                )
-                model_to_resize.resize_token_embeddings(len(self.tokenizer))
-
-                model_to_resize = (
-                    self.model.discriminator_model.module
-                    if hasattr(self.model.discriminator_model, "module")
-                    else self.model.discriminator_model
-                )
-                model_to_resize.resize_token_embeddings(len(self.tokenizer))
-            else:
-                self.model = model_class(config=self.config)
-                model_to_resize = self.model.module if hasattr(self.model, "module") else self.model
-                model_to_resize.resize_token_embeddings(len(self.tokenizer))
-
+            self.model = model
         if model_type in ["camembert", "xlmroberta"]:
             warnings.warn(
                 f"use_multiprocessing automatically disabled as {model_type}"
@@ -390,11 +402,11 @@ class LanguageModelingModel:
 
         def collate(examples: List[torch.Tensor]):
             if tokenizer._pad_token is None:
-                return pad_sequence(examples, batch_first=True)
+                return pad_sequence(examples, batch_first=True, padding_value=-100)
             return pad_sequence(examples, batch_first=True, padding_value=tokenizer.pad_token_id)
 
         if self.is_world_master():
-            tb_writer = SummaryWriter(logdir=args.tensorboard_dir)
+            tb_writer = SummaryWriter(log_dir=args.tensorboard_dir)
         train_sampler = RandomSampler(train_dataset) if args.local_rank == -1 else DistributedSampler(train_dataset)
         if self.args.use_hf_datasets:
             # Inputs are already padded so default collation is fine
@@ -931,7 +943,7 @@ class LanguageModelingModel:
 
         def collate(examples: List[torch.Tensor]):
             if tokenizer._pad_token is None:
-                return pad_sequence(examples, batch_first=True)
+                return pad_sequence(examples, batch_first=True, padding_value=-100)
             return pad_sequence(examples, batch_first=True, padding_value=tokenizer.pad_token_id)
 
         eval_sampler = SequentialSampler(eval_dataset)
