@@ -13,7 +13,6 @@ from datasets import load_dataset
 from torch.utils.data import Dataset
 from tqdm.auto import tqdm
 from transformers import BertTokenizer
-
 from loguru import logger
 
 jieba.setLogLevel('ERROR')
@@ -35,7 +34,6 @@ class ZHTokenizer(BertTokenizer):
         return split_tokens
 
 
-
 def preprocess_batch_for_hf_dataset(dataset, tokenizer, args):
     if args.preprocess_inputs:
         return tokenizer.prepare_seq2seq_batch(
@@ -45,6 +43,7 @@ def preprocess_batch_for_hf_dataset(dataset, tokenizer, args):
             ],
             tgt_texts=dataset["target_text"],
             max_length=args.max_seq_length,
+            max_target_length=args.max_length,
             padding="max_length",
             return_tensors="np",
             truncation=True,
@@ -57,6 +56,7 @@ def preprocess_batch_for_hf_dataset(dataset, tokenizer, args):
             ],
             tgt_texts=dataset["target_text"],
             max_length=args.max_seq_length,
+            max_target_length=args.max_length,
             padding="max_length",
             return_tensors="np",
             truncation=True,
@@ -103,41 +103,15 @@ def preprocess_data(data):
             return_tensors="pt",
             truncation=True,
         )
-        # input_text = tokenizer.encode(
-        #     prefix + ": " + input_text,
-        #     max_length=args.max_seq_length,
-        #     padding="max_length",
-        #     return_tensors="pt",
-        #     truncation=True,
-        # )
-
-        # target_text = tokenizer.encode(
-        #     target_text,
-        #     max_length=args.max_seq_length,
-        #     padding="max_length",
-        #     return_tensors="pt",
-        #     truncation=True,
-        # )
     else:
         batch = tokenizer.prepare_seq2seq_batch(
-            src_texts=[prefix + input_text],
+            src_texts=[prefix + ": " + input_text],
             tgt_texts=[target_text],
             max_length=args.max_seq_length,
             padding="max_length",
             return_tensors="pt",
             truncation=True,
         )
-        # input_text = tokenizer.encode(
-        #     prefix + input_text,
-        #     max_length=args.max_seq_length,
-        #     padding="max_length",
-        #     return_tensors="pt",
-        #     truncation=True,
-        # )
-
-        # target_text = tokenizer.encode(
-        #     target_text, max_length=args.max_seq_length, padding="max_length", return_tensors="pt", truncation=True
-        # )
     input_ids = batch["input_ids"][0]
     attention_mask = batch["attention_mask"][0]
     labels = batch["labels"][0]
@@ -155,14 +129,14 @@ class T5Dataset(Dataset):
         )
 
         if os.path.exists(cached_features_file) and (
-            (not args.reprocess_input_data and not args.no_cache)
-            or (mode == "dev" and args.use_cached_eval_features and not args.no_cache)
+                (not args.reprocess_input_data and not args.no_cache)
+                or (mode == "dev" and args.use_cached_eval_features and not args.no_cache)
         ):
-            logger.info(" Loading features from cached file %s", cached_features_file)
+            logger.info(" Loading features from cached file %s" % cached_features_file)
             with open(cached_features_file, "rb") as handle:
                 self.examples = pickle.load(handle)
         else:
-            logger.info(" Creating features from dataset file at %s", args.cache_dir)
+            logger.info(" Creating features from dataset file at %s" % args.cache_dir)
 
             data = [
                 (prefix, input_text, target_text, tokenizer, args)
@@ -172,7 +146,7 @@ class T5Dataset(Dataset):
             ]
 
             if (mode == "train" and args.use_multiprocessing) or (
-                mode == "dev" and args.use_multiprocessing_for_evaluation
+                    mode == "dev" and args.use_multiprocessing_for_evaluation
             ):
                 if args.multiprocessing_chunksize == -1:
                     chunksize = max(len(data) // (args.process_count * 2), 500)
@@ -194,7 +168,7 @@ class T5Dataset(Dataset):
 
             if not args.no_cache:
                 logger.info(
-                    " Saving features into cached file %s", cached_features_file
+                    " Saving features into cached file %s" % cached_features_file
                 )
                 with open(cached_features_file, "wb") as handle:
                     pickle.dump(self.examples, handle, protocol=pickle.HIGHEST_PROTOCOL)
